package com.cooleshow.base.ui.activity

import android.os.Bundle
import androidx.viewbinding.ViewBinding
import com.cooleshow.base.common.AppManager
import com.cooleshow.base.presenter.view.BaseView
import com.cooleshow.base.utils.ToastUtils
import com.cooleshow.base.utils.helper.QMUIStatusBarHelper
import com.cooleshow.base.widgets.ProgressLoading
import com.trello.rxlifecycle4.components.support.RxAppCompatActivity

/*
    Activity基类，业务无关
 */
abstract class BaseActivity<V : ViewBinding> : RxAppCompatActivity(), BaseView {
    lateinit var mLoading: ProgressLoading;
    lateinit var viewBinding: V;

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        viewBinding = getLayoutView()
        setContentView(viewBinding?.root)
        AppManager.instance.addActivity(this)
        QMUIStatusBarHelper.translucent(this)
        initView()
        initData()
    }

    protected abstract fun getLayoutView(): V

    protected abstract fun initView()

    open fun initData() {
        mLoading = ProgressLoading.create(this);
    }

    override fun showLoading() {
        mLoading?.showLoading()
    }

    override fun hideLoading() {
        mLoading?.hideLoading()
    }

    override fun onError(throwable: Throwable) {
        ToastUtils.showShort("onError:${throwable.message}")
    }

    override fun onDestroy() {
        super.onDestroy()
        AppManager.instance.finishActivity(this)
        mLoading?.stopAnim()
    }
}
