package com.cooleshow.teacher.ui.main

import android.view.MotionEvent
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.chad.library.adapter.base.listener.OnItemClickListener
import com.cooleshow.base.ui.fragment.BaseMVPFragment
import com.cooleshow.base.utils.SizeUtils
import com.cooleshow.base.utils.TimeUtils
import com.cooleshow.base.utils.ToastUtils
import com.cooleshow.teacher.R
import com.cooleshow.teacher.adapter.CourseTableListAdapter
import com.cooleshow.teacher.bean.CourseTableListBean
import com.cooleshow.teacher.contract.CourseTableContract
import com.cooleshow.teacher.contract.HomeContract
import com.cooleshow.teacher.databinding.FragmentCourseTableLayoutBinding
import com.cooleshow.teacher.presenter.main.CourseTablePresenter
import com.cooleshow.teacher.presenter.main.HomePresenter
import com.cooleshow.teacher.widgets.CalendarExpandDecoration
import com.cooleshow.teacher.widgets.CalendarShrinkDecoration
import com.haibin.calendarview.CalendarView
import kotlinx.android.synthetic.main.fragment_course_table_layout.*
import java.util.*


/**
 * Author by pq, Date on 2022/4/20.
 */
class CourseTableFragment :
    BaseMVPFragment<FragmentCourseTableLayoutBinding, CourseTablePresenter>(),
    HomeContract.HomeView, CalendarView.OnCalendarSelectListener,
    CalendarView.OnCalendarInterceptListener, CalendarView.OnMonthChangeListener,
    CalendarView.OnViewChangeListener, CourseTableContract.CourseTableView {
    private lateinit var date: Date
    private lateinit var calendarDate: String
    private lateinit var calendarExpandDecoration: CalendarExpandDecoration
    private lateinit var calendarShrinkDecoration: CalendarShrinkDecoration
    private lateinit var adapter: CourseTableListAdapter
    private var day: Int = -1;

    override fun getLayoutView(): FragmentCourseTableLayoutBinding {
        return FragmentCourseTableLayoutBinding.inflate(layoutInflater)
    }

    override fun initView(rootView: View?) {
        mViewBinding.calendarView.setOnCalendarSelectListener(this)
        mViewBinding.calendarView.setOnCalendarInterceptListener(this)
        mViewBinding.calendarView.setOnMonthChangeListener(this)
        mViewBinding.calendarView.setOnViewChangeListener(this)
        calendarExpandDecoration = CalendarExpandDecoration(context)
        calendarShrinkDecoration = CalendarShrinkDecoration(context)
        val layoutManager = LinearLayoutManager(
            activity
        )
        mViewBinding.recyclerView.layoutManager = layoutManager
        mViewBinding.recyclerView.addItemDecoration(calendarShrinkDecoration, 0)
        adapter = CourseTableListAdapter(R.layout.item_course_table_layout);

        mViewBinding.recyclerView.adapter = adapter
        mViewBinding.recyclerView.addOnItemTouchListener(object :
            RecyclerView.SimpleOnItemTouchListener() {
            var y = 0f
            override fun onInterceptTouchEvent(rv: RecyclerView, e: MotionEvent): Boolean {
                when (e.action) {
                    MotionEvent.ACTION_DOWN -> y = e.y
                    MotionEvent.ACTION_UP -> {
                        val right: Int = rv.width / 2 - SizeUtils.dp2px(16f)
                        val left: Int = rv.width / 2 + SizeUtils.dp2px(16f)
                        if (right < e.x && e.x < left && e.y < SizeUtils.dp2px(30f) && y < SizeUtils.dp2px(
                                30f
                            )
                        ) {
                            if (mViewBinding.calendarLayout.isExpand) {
                                mViewBinding.calendarLayout.shrink()
                            } else {
                                mViewBinding.calendarLayout.expand()
                            }
                            return true
                        }
                    }
                }
                return super.onInterceptTouchEvent(rv, e)
            }
        })
        adapter.setOnItemClickListener(OnItemClickListener() { adapter, view, position ->
            ToastUtils.showShort("点击position:" + position)
            presenter.getCourseScheduleDateByMonth(calendarDate)
        })
        addTestData()
    }

    private fun addTestData() {
        var list = mutableListOf<CourseTableListBean?>()
        for (i in 0 until 20) {
            list.add(CourseTableListBean())
        }
        adapter.setNewInstance(list)
    }

    override fun initData() {
        lazyLoad()
    }

    private fun lazyLoad() {
        val calendar = Calendar.getInstance()
        val year = calendar[Calendar.YEAR]
        val month = calendar[Calendar.MONTH] + 1
        day = calendar[Calendar.DAY_OF_MONTH]
        if ((mViewBinding.calendarView.getCurDay() !== day || mViewBinding.calendarView.getCurMonth() !== month || mViewBinding.calendarView.getCurYear() !== year)) {
            mViewBinding.calendarView.updateCurrentDate()
            mViewBinding.calendarView.clearSingleSelect()
        }
        setMontAndDay(year, month, day)
        date = TimeUtils.getNowDate()
        calendarDate = TimeUtils.getNowString(TimeUtils.getSafeDateFormat("yyyy-MM"))
        presenter.getCourseScheduleDateByMonth(calendarDate)
        presenter.getCourseSchedulesWithDate(date)
    }

    private fun setMontAndDay(year: Int, month: Int, day: Int) {
        var span: String = if (month < 10) {
            year.toString() + "年0" + month + "月"
        } else {
            year.toString() + "年" + month + "月"
        }
        mViewBinding.tvCurrentDate.text = span
    }

    override fun onCalendarOutOfRange(calendar: com.haibin.calendarview.Calendar?) {
    }

    override fun onCalendarSelect(calendar: com.haibin.calendarview.Calendar?, isClick: Boolean) {
        val year = calendar!!.year
        val month = calendar!!.month
        val day = calendar!!.day
        setMontAndDay(year, month, day)
    }

    override fun onCalendarIntercept(calendar: com.haibin.calendarview.Calendar?): Boolean {
        return false;
    }

    override fun onCalendarInterceptClick(
        calendar: com.haibin.calendarview.Calendar?,
        isClick: Boolean
    ) {
    }

    override fun onMonthChange(year: Int, month: Int) {
        setMontAndDay(year, month, day)
    }

    override fun onViewChange(isMonthView: Boolean) {
        if (!isMonthView) {
            recyclerView.removeItemDecoration(calendarExpandDecoration)
            if (recyclerView.itemDecorationCount == 0 || recyclerView.getItemDecorationAt(0) !is CalendarShrinkDecoration) {
                recyclerView.addItemDecoration(calendarShrinkDecoration, 0)
            }
        } else {
            recyclerView.removeItemDecoration(calendarShrinkDecoration)
            if (recyclerView.itemDecorationCount == 0 || recyclerView.getItemDecorationAt(0) !is CalendarExpandDecoration) {
                recyclerView.addItemDecoration(calendarExpandDecoration, 0)
            }
        }
    }

    override fun createPresenter(): CourseTablePresenter {
        return CourseTablePresenter()
    }

    /**
     * 根据月份查询当月有课的日期
     */
    override fun onGetCourseDateByMonthSuccess(datas: MutableList<String>?) {
        if (isDetached) {
            return;
        }
        if (datas?.size != 0) {

        }
    }
}