package com.cooleshow.usercenter.ui.activity

import android.os.Bundle
import android.text.TextUtils
import com.alibaba.android.arouter.facade.annotation.Route
import com.alibaba.android.arouter.launcher.ARouter
import com.cooleshow.base.data.net.CommonParamsHelper
import com.cooleshow.base.ext.onClick
import com.cooleshow.base.ui.activity.BaseMVPActivity
import com.cooleshow.base.utils.ToastUtils
import com.cooleshow.base.utils.helper.QMUIStatusBarHelper
import com.cooleshow.provider.router.RouterPath
import com.cooleshow.usercenter.bean.UserInfo
import com.cooleshow.usercenter.databinding.ActivityLoginBinding
import com.cooleshow.usercenter.helper.UserHelper
import com.cooleshow.usercenter.presenter.LoginPresenter
import com.cooleshow.usercenter.presenter.contract.LoginContract
import kotlinx.android.synthetic.main.activity_login.*

@Route(path = RouterPath.UserCenter.PATH_LOGIN)
class LoginActivity : BaseMVPActivity<ActivityLoginBinding, LoginPresenter>(),
    LoginContract.LoginView {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        QMUIStatusBarHelper.setStatusBarLightMode(this);
    }

    override fun getLayoutView(): ActivityLoginBinding {
        return ActivityLoginBinding.inflate(layoutInflater)
    }

    override fun createPresenter(): LoginPresenter {
        return LoginPresenter()
    }

    override fun initView() {
        tv_login_by_code.onClick {
            ARouter.getInstance().build(RouterPath.UserCenter.PATH_VERIFY_LOGIN).navigation()
        }

        mLoginBtn.setOnClickListener {
            if (TextUtils.isEmpty(et_phone_num?.text)) {
                ToastUtils.showShort("手机号不可为空")
                return@setOnClickListener;
            }
            if (TextUtils.isEmpty(et_password?.text)) {
                ToastUtils.showShort("密码不可为空")
                return@setOnClickListener;
            }
            presenter?.onLoginByPwd(et_phone_num?.text.toString(), et_password?.text.toString());
        }
    }

    /**
     * 登录成功
     */
    override fun onLoginResult(result: UserInfo) {
        if (isFinishing || isDestroyed) {
            return;
        }
        var token = UserHelper.buildToken(
            result.authentication?.token_type,
            result.authentication?.access_token
        )
        UserHelper.saveUserToken(token);

        //添加公共参数
        CommonParamsHelper.getInstance().addCommonHeaderParams(CommonParamsHelper.USER_TOKEN, token);
        ARouter.getInstance().build(RouterPath.APPCenter.PATH_HOME).navigation()
    }

}